package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppletAnswerBase;
import com.ruoyi.model.service.IAppletAnswerBaseService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户基本考核答案Controller
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
@RestController
@RequestMapping("/model/AppletAnswerBase")
public class AppletAnswerBaseController extends BaseController
{
    @Autowired
    private IAppletAnswerBaseService appletAnswerBaseService;

    /**
     * 查询用户基本考核答案列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswerBase:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppletAnswerBase appletAnswerBase)
    {
        startPage();
        List<AppletAnswerBase> list = appletAnswerBaseService.selectAppletAnswerBaseList(appletAnswerBase);
        return getDataTable(list);
    }

    /**
     * 导出用户基本考核答案列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswerBase:export')")
    @Log(title = "用户基本考核答案", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppletAnswerBase appletAnswerBase) throws IOException {
        List<AppletAnswerBase> list = appletAnswerBaseService.selectAppletAnswerBaseList(appletAnswerBase);
        ExcelUtil<AppletAnswerBase> util = new ExcelUtil<AppletAnswerBase>(AppletAnswerBase.class);
        util.exportExcel(response, list, "用户基本考核答案数据");
    }

    /**
     * 获取用户基本考核答案详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswerBase:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appletAnswerBaseService.selectAppletAnswerBaseById(id));
    }

    /**
     * 新增用户基本考核答案
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswerBase:add')")
    @Log(title = "用户基本考核答案", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppletAnswerBase appletAnswerBase)
    {
        return toAjax(appletAnswerBaseService.insertAppletAnswerBase(appletAnswerBase));
    }

    /**
     * 修改用户基本考核答案
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswerBase:edit')")
    @Log(title = "用户基本考核答案", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppletAnswerBase appletAnswerBase)
    {
        return toAjax(appletAnswerBaseService.updateAppletAnswerBase(appletAnswerBase));
    }

    /**
     * 删除用户基本考核答案
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswerBase:remove')")
    @Log(title = "用户基本考核答案", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appletAnswerBaseService.deleteAppletAnswerBaseByIds(ids));
    }
}
